pub struct CallbackEffects<'ctx, 'id, R: NodeRuntime + ?Sized = dyn NodeRuntime + 'ctx> { /* private fields */ }Expand description
Builder for optional callback effect metadata.
Implementations
Sourceimpl<'ctx, 'id, R: NodeRuntime + ?Sized> CallbackEffects<'ctx, 'id, R>
impl<'ctx, 'id, R: NodeRuntime + ?Sized> CallbackEffects<'ctx, 'id, R>
Sourcepub fn reads_entity(self, entity: &impl DeclaredEntity) -> NodeResult<Self>
pub fn reads_entity(self, entity: &impl DeclaredEntity) -> NodeResult<Self>
Record that callback reads from a declared entity handle.
Sourcepub fn publishes_entity(self, entity: &impl DeclaredEntity) -> NodeResult<Self>
pub fn publishes_entity(self, entity: &impl DeclaredEntity) -> NodeResult<Self>
Record that callback publishes via a declared entity handle.
Sourcepub fn writes_entity(self, entity: &impl DeclaredEntity) -> NodeResult<Self>
pub fn writes_entity(self, entity: &impl DeclaredEntity) -> NodeResult<Self>
Record that callback writes to a declared entity handle.