NodeRuntimeAdapter

Struct NodeRuntimeAdapter 

pub struct NodeRuntimeAdapter<'a, R: DeclaredNodeRuntime + ?Sized, const MAX_NODES: usize = { crate::node_metadata::DEFAULT_MAX_METADATA_NODES }, const MAX_ENTITIES: usize = { crate::node_metadata::DEFAULT_MAX_METADATA_ENTITIES }, const MAX_CALLBACKS: usize = { crate::node_metadata::DEFAULT_MAX_METADATA_CALLBACKS }> { /* private fields */ }
Runtime adapter used by generated main ownership code.

Implementations

Source

impl<'a, R: DeclaredNodeRuntime + ?Sized, const MAX_NODES: usize, const MAX_ENTITIES: usize, const MAX_CALLBACKS: usize> NodeRuntimeAdapter<'a, R, MAX_NODES, MAX_ENTITIES, MAX_CALLBACKS>

pub fn new(node_runtime: &'a mut R) -> Self

Build a runtime adapter around a generated executor owner.

pub fn nodes(&self) -> &[RuntimeNodeRecord<R::NodeHandle>]

Runtime node mappings in declaration order.

pub fn entities(&self) -> &[EntityMetadata]

Entity declarations accepted for generated runtime binding.

pub fn callback_effects(&self) -> &[CallbackEffectMetadata]

Optional callback effects accepted for generated runtime binding.

pub fn node_handle(&self, stable_id: NodeId<'_>) -> Option<R::NodeHandle>

Lookup an executor node handle by stable component node ID.