ClockType

Enum ClockType 

pub enum ClockType {
    SystemTime,
    SteadyTime,
    RosTime,
}
Type of clock to use for time queries

Variants



SystemTime

System time (wall clock)

This clock reflects the system’s real-time clock and may be affected by NTP adjustments, user changes, or daylight saving time. Use for timestamps that need to correlate with real-world time.



SteadyTime

Steady/monotonic time

This clock is guaranteed to be monotonically increasing and is not affected by system time changes. Use for measuring durations and timeouts.



RosTime

ROS time (simulation time)

This clock can be overridden for simulation purposes. When a ROS time override is active, now() returns the overridden time. Otherwise, it falls back to system time.