pub struct SpinPeriodPollingResult {
pub work: SpinOnceResult,
pub remaining_ms: u64,
}Expand description
Result from a single period of polling execution (no_std compatible).
Contains the work performed and the remaining time the caller should sleep. The caller is responsible for the actual delay (platform-specific).
Example
ⓘ
loop {
let r = executor.spin_one_period(10, elapsed_ms);
platform_sleep_ms(r.remaining_ms);
}Fields
work: SpinOnceResultWork performed during this iteration
remaining_ms: u64Remaining time in ms that the caller should sleep