pub struct NodeRuntimeAdapter<'a, R: DeclaredNodeRuntime + ?Sized, const MAX_NODES: usize = { crate::node_metadata::DEFAULT_MAX_METADATA_NODES }, const MAX_ENTITIES: usize = { crate::node_metadata::DEFAULT_MAX_METADATA_ENTITIES }, const MAX_CALLBACKS: usize = { crate::node_metadata::DEFAULT_MAX_METADATA_CALLBACKS }> { /* private fields */ }Expand description
Runtime adapter used by generated main ownership code.
Implementations
Sourceimpl<'a, R: DeclaredNodeRuntime + ?Sized, const MAX_NODES: usize, const MAX_ENTITIES: usize, const MAX_CALLBACKS: usize> NodeRuntimeAdapter<'a, R, MAX_NODES, MAX_ENTITIES, MAX_CALLBACKS>
impl<'a, R: DeclaredNodeRuntime + ?Sized, const MAX_NODES: usize, const MAX_ENTITIES: usize, const MAX_CALLBACKS: usize> NodeRuntimeAdapter<'a, R, MAX_NODES, MAX_ENTITIES, MAX_CALLBACKS>
Sourcepub fn new(node_runtime: &'a mut R) -> Self
pub fn new(node_runtime: &'a mut R) -> Self
Build a runtime adapter around a generated executor owner.
Sourcepub fn nodes(&self) -> &[RuntimeNodeRecord<R::NodeHandle>]
pub fn nodes(&self) -> &[RuntimeNodeRecord<R::NodeHandle>]
Runtime node mappings in declaration order.
Sourcepub fn entities(&self) -> &[EntityMetadata]
pub fn entities(&self) -> &[EntityMetadata]
Entity declarations accepted for generated runtime binding.
Sourcepub fn callback_effects(&self) -> &[CallbackEffectMetadata]
pub fn callback_effects(&self) -> &[CallbackEffectMetadata]
Optional callback effects accepted for generated runtime binding.
Sourcepub fn node_handle(&self, stable_id: NodeId<'_>) -> Option<R::NodeHandle>
pub fn node_handle(&self, stable_id: NodeId<'_>) -> Option<R::NodeHandle>
Lookup an executor node handle by stable component node ID.